EasyExtend.util.hexobject.HexOrBin

Package EasyExtend :: Package util :: Module hexobject :: Class HexOrBin |
[hide private]
[frames] | no frames]

# Class HexOrBin

    object --+
             |
            HexOrBin

Known Subclasses:
  - Hex

Instance Methods | [hide private]
Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__init__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Properties | [hide private]
Inherited from `object`: `__class__`